@@ -29,7 +29,7 @@ EUCAST_VERSION_EXPERT_RULES <- "3.1, 2016"
 #' @param x data with antibiotic columns, like e.g. \code{AMX} and \code{AMC}
 #' @param info print progress
 #' @param rules a character vector that specifies which rules should be applied - one or more of \code{c("breakpoints", "expert", "other", "all")}
-#' @param verbose a logical to indicate whether extensive info should be returned as a \code{data.frame} with info about which rows and columns are effected. It runs all EUCAST rules, but will not be applied to an output - only an informative \code{data.frame} with changes will be returned as output.
+#' @param verbose a logical to turn Verbose mode on and off (default is off). In Verbose mode, the function does not apply rules to the data, but instead returns a data set in logbook form with extensive info about which rows and columns would be effected and in which way.
 #' @param ... column name of an antibiotic, see section Antibiotics
 #' @inheritParams first_isolate
 #' @details
@@ -41,7 +41,7 @@ EUCAST_VERSION_EXPERT_RULES <- "3.1, 2016"
 #' @section Antibiotics:
 #' To define antibiotics column names, leave as it is to determine it automatically with \code{\link{guess_ab_col}} or input a text (case-insensitive), or use \code{NULL} to skip a column (e.g. \code{TIC = NULL} to skip ticarcillin). Manually defined but non-existing columns will be skipped with a warning.
 #'
-#' The following antibiotics are used for the functions \code{\link{eucast_rules}} and \code{\link{mdro}}. These are shown in the format '\strong{antimicrobial ID}: name (\emph{ATC code})', sorted by name:
+#' The following antibiotics are used for the functions \code{\link{eucast_rules}} and \code{\link{mdro}}. These are shown below in the format '\strong{antimicrobial ID}: name (\href{https://www.whocc.no/atc/structure_and_principles/}{ATC code})', sorted by name:
 #'
 #'  \strong{AMK}: amikacin (\href{https://www.whocc.no/atc_ddd_index/?code=J01GB06}{J01GB06}),
 #'  \strong{AMX}: amoxicillin (\href{https://www.whocc.no/atc_ddd_index/?code=J01CA04}{J01CA04}),
@@ -119,7 +119,8 @@ EUCAST_VERSION_EXPERT_RULES <- "3.1, 2016"
 #' @rdname eucast_rules
 #' @export
 #' @importFrom dplyr %>% select pull mutate_at vars group_by summarise n
-#' @importFrom crayon bold bgGreen bgYellow bgRed black green blue italic strip_style white
+#' @importFrom crayon bold bgGreen bgYellow bgRed black green blue italic strip_style white red make_style
+#' @importFrom utils menu
 #' @return The input of \code{x}, possibly with edited values of antibiotics. Or, if \code{verbose = TRUE}, a \code{data.frame} with all original and new values of the affected bug-drug combinations.
 #' @source
 #'   \itemize{
@@ -139,8 +140,6 @@ EUCAST_VERSION_EXPERT_RULES <- "3.1, 2016"
 #'   }
 #' @inheritSection AMR Read more on our website!
 #' @examples
-#' a <- eucast_rules(septic_patients)
-#'
 #' a <- data.frame(mo = c("Staphylococcus aureus",
 #'                        "Enterococcus faecalis",
 #'                        "Escherichia coli",
@@ -176,22 +175,37 @@ EUCAST_VERSION_EXPERT_RULES <- "3.1, 2016"
 #' # 5 Pseudomonas aeruginosa    R    R    -    -    R    R    R
 #'
 #'
-#' # do not apply EUCAST rules, but rather get a a data.frame
+#' \donttest{
+#' # do not apply EUCAST rules, but rather get a data.frame
 #' # with 18 rows, containing all details about the transformations:
 #' c <- eucast_rules(a, verbose = TRUE)
+#' }
 eucast_rules <- function(x,
                          col_mo = NULL,
                          info = TRUE,
                          rules = c("breakpoints", "expert", "other", "all"),
                          verbose = FALSE,
                          ...) {
-
-  x <- x
-
+  
+  if (verbose == TRUE & interactive()) {
+    txt <- paste0("WARNING: In Verbose mode, the eucast_rules() function does not apply rules to the data, but instead returns a data set in logbook form with extensive info about which rows and columns would be effected and in which way.",
+                  "\n\nThis may overwrite your existing data if you use e.g.:",
+                  "\ndata <- eucast_rules(data, verbose = TRUE)\n\nDo you want to continue?")
+    if ("rstudioapi" %in% rownames(utils::installed.packages())) {
+      q_continue <- rstudioapi::showQuestion("Using verbose = TRUE with eucast_rules()", txt)
+    } else {
+      q_continue <- menu(choices = c("OK", "Cancel"), graphics = TRUE, title = txt)
+    }
+    if (q_continue %in% c(FALSE, 2)) {
+      message("Cancelled, returning original data")
+      return(x)
+    }
+  }
+  
   if (!is.data.frame(x)) {
     stop("`x` must be a data frame.", call. = FALSE)
   }
-
+  
   # try to find columns based on type
   # -- mo
   if (is.null(col_mo)) {
@@ -200,40 +214,68 @@ eucast_rules <- function(x,
   if (is.null(col_mo)) {
     stop("`col_mo` must be set.", call. = FALSE)
   }
-
+  
   if (!all(rules %in% c("breakpoints", "expert", "other", "all"))) {
     stop("`rules` must be one or more of:  'breakpoints', 'expert', 'other', 'all'.")
   }
-
+  
   if (is.null(col_mo)) {
     stop("`col_mo` must be set")
   }
-
+  
   decimal.mark <- getOption("OutDec")
   big.mark <- ifelse(decimal.mark != ",", ",", ".")
   formatnr <- function(x) {
     trimws(format(x, big.mark = big.mark, decimal.mark = decimal.mark))
   }
-
+  
+  grey <- make_style("grey")
+  
   warned <- FALSE
-
-  txt_error <- function() { cat("", bgRed(white(" ERROR ")), "\n") }
-  txt_warning <- function() { if (warned == FALSE) { cat("", bgYellow(black(" WARNING ")), "\n") }; warned <<- TRUE }
-  txt_ok <- function(no_of_changes) {
+  
+  txt_error <- function() {
+    cat("", bgRed(white(" ERROR ")), "\n\n") 
+  }
+  txt_warning <- function() {
     if (warned == FALSE) {
-      if (no_of_changes > 0) {
-        if (no_of_changes == 1) {
-          cat(blue(" (1 new change)\n"))
-        } else {
-          cat(blue(paste0(" (", formatnr(no_of_changes), " new changes)\n")))
-        }
+      cat("", bgYellow(black(" WARNING ")))
+    }
+    warned <<- TRUE 
+  }
+  txt_ok <- function(no_added, no_changed) {
+    if (warned == FALSE) {
+      if (no_added + no_changed == 0) {
+        cat(pillar::style_subtle(" (no changes)\n"))
       } else {
-        cat(green(" (no new changes)\n"))
+        # opening
+        cat(grey(" ("))
+        # additions
+        if (no_added > 0) {
+          if (no_added == 1) {
+            cat(green("1 value added"))
+          } else {
+            cat(green(formatnr(no_added), "values added"))
+          }
+        }
+        # separator
+        if (no_added > 0 & no_changed > 0) {
+          cat(grey(", "))
+        }
+        # changes
+        if (no_changed > 0) {
+          if (no_changed == 1) {
+            cat(blue("1 value changed"))
+          } else {
+            cat(blue(formatnr(no_changed), "values changed"))
+          }
+        } 
+        # closing
+        cat(grey(")\n"))
       }
       warned <<- FALSE
     }
   }
-
+  
   cols_ab <- get_column_abx(x = x,
                             soft_dependencies = c("AMC",
                                                   "AMK",
@@ -301,141 +343,162 @@ eucast_rules <- function(x,
                             hard_dependencies = NULL,
                             verbose = verbose,
                             ...)
-
-  AMC <- cols_ab['AMC']
-  AMK <- cols_ab['AMK']
-  AMP <- cols_ab['AMP']
-  AMX <- cols_ab['AMX']
-  ATM <- cols_ab['ATM']
-  AZL <- cols_ab['AZL']
-  AZM <- cols_ab['AZM']
-  CAZ <- cols_ab['CAZ']
-  CED <- cols_ab['CED']
-  CHL <- cols_ab['CHL']
-  CIP <- cols_ab['CIP']
-  CLI <- cols_ab['CLI']
-  CLR <- cols_ab['CLR']
-  COL <- cols_ab['COL']
-  CRO <- cols_ab['CRO']
-  CTX <- cols_ab['CTX']
-  CXM <- cols_ab['CXM']
-  CZO <- cols_ab['CZO']
-  DAP <- cols_ab['DAP']
-  DOX <- cols_ab['DOX']
-  ERY <- cols_ab['ERY']
-  ETP <- cols_ab['ETP']
-  FEP <- cols_ab['FEP']
-  FLC <- cols_ab['FLC']
-  FOS <- cols_ab['FOS']
-  FOX <- cols_ab['FOX']
-  FUS <- cols_ab['FUS']
-  GEN <- cols_ab['GEN']
-  IPM <- cols_ab['IPM']
-  KAN <- cols_ab['KAN']
-  LIN <- cols_ab['LIN']
-  LNZ <- cols_ab['LNZ']
-  LVX <- cols_ab['LVX']
-  MEM <- cols_ab['MEM']
-  MEZ <- cols_ab['MEZ']
-  MFX <- cols_ab['MFX']
-  MNO <- cols_ab['MNO']
-  NAL <- cols_ab['NAL']
-  NEO <- cols_ab['NEO']
-  NET <- cols_ab['NET']
-  NIT <- cols_ab['NIT']
-  NOR <- cols_ab['NOR']
-  NOV <- cols_ab['NOV']
-  OFX <- cols_ab['OFX']
-  OXA <- cols_ab['OXA']
-  PEN <- cols_ab['PEN']
-  PIP <- cols_ab['PIP']
-  PLB <- cols_ab['PLB']
-  PRI <- cols_ab['PRI']
-  QDA <- cols_ab['QDA']
-  RID <- cols_ab['RID']
-  RIF <- cols_ab['RIF']
-  RXT <- cols_ab['RXT']
-  SIS <- cols_ab['SIS']
-  SXT <- cols_ab['SXT']
-  TCY <- cols_ab['TCY']
-  TEC <- cols_ab['TEC']
-  TGC <- cols_ab['TGC']
-  TIC <- cols_ab['TIC']
-  TMP <- cols_ab['TMP']
-  TOB <- cols_ab['TOB']
-  TZP <- cols_ab['TZP']
-  VAN <- cols_ab['VAN']
-
+  
+  AMC <- cols_ab["AMC"]
+  AMK <- cols_ab["AMK"]
+  AMP <- cols_ab["AMP"]
+  AMX <- cols_ab["AMX"]
+  ATM <- cols_ab["ATM"]
+  AZL <- cols_ab["AZL"]
+  AZM <- cols_ab["AZM"]
+  CAZ <- cols_ab["CAZ"]
+  CED <- cols_ab["CED"]
+  CHL <- cols_ab["CHL"]
+  CIP <- cols_ab["CIP"]
+  CLI <- cols_ab["CLI"]
+  CLR <- cols_ab["CLR"]
+  COL <- cols_ab["COL"]
+  CRO <- cols_ab["CRO"]
+  CTX <- cols_ab["CTX"]
+  CXM <- cols_ab["CXM"]
+  CZO <- cols_ab["CZO"]
+  DAP <- cols_ab["DAP"]
+  DOX <- cols_ab["DOX"]
+  ERY <- cols_ab["ERY"]
+  ETP <- cols_ab["ETP"]
+  FEP <- cols_ab["FEP"]
+  FLC <- cols_ab["FLC"]
+  FOS <- cols_ab["FOS"]
+  FOX <- cols_ab["FOX"]
+  FUS <- cols_ab["FUS"]
+  GEN <- cols_ab["GEN"]
+  IPM <- cols_ab["IPM"]
+  KAN <- cols_ab["KAN"]
+  LIN <- cols_ab["LIN"]
+  LNZ <- cols_ab["LNZ"]
+  LVX <- cols_ab["LVX"]
+  MEM <- cols_ab["MEM"]
+  MEZ <- cols_ab["MEZ"]
+  MFX <- cols_ab["MFX"]
+  MNO <- cols_ab["MNO"]
+  NAL <- cols_ab["NAL"]
+  NEO <- cols_ab["NEO"]
+  NET <- cols_ab["NET"]
+  NIT <- cols_ab["NIT"]
+  NOR <- cols_ab["NOR"]
+  NOV <- cols_ab["NOV"]
+  OFX <- cols_ab["OFX"]
+  OXA <- cols_ab["OXA"]
+  PEN <- cols_ab["PEN"]
+  PIP <- cols_ab["PIP"]
+  PLB <- cols_ab["PLB"]
+  PRI <- cols_ab["PRI"]
+  QDA <- cols_ab["QDA"]
+  RID <- cols_ab["RID"]
+  RIF <- cols_ab["RIF"]
+  RXT <- cols_ab["RXT"]
+  SIS <- cols_ab["SIS"]
+  SXT <- cols_ab["SXT"]
+  TCY <- cols_ab["TCY"]
+  TEC <- cols_ab["TEC"]
+  TGC <- cols_ab["TGC"]
+  TIC <- cols_ab["TIC"]
+  TMP <- cols_ab["TMP"]
+  TOB <- cols_ab["TOB"]
+  TZP <- cols_ab["TZP"]
+  VAN <- cols_ab["VAN"]
+  
   ab_missing <- function(ab) {
     all(ab %in% c(NULL, NA))
   }
-
+  
   verbose_info <- data.frame(row = integer(0),
                              col = character(0),
                              mo_fullname = character(0),
-                             old = character(0),
-                             new = character(0),
+                             old = as.rsi(character(0)),
+                             new = as.rsi(character(0)),
                              rule = character(0),
                              rule_group = character(0),
                              rule_name = character(0),
                              stringsAsFactors = FALSE)
-
+  
   # helper function for editing the table
   edit_rsi <- function(to, rule, rows, cols) {
     cols <- unique(cols[!is.na(cols) & !is.null(cols)])
     if (length(rows) > 0 & length(cols) > 0) {
       before_df <- x_original
-      before <- as.character(unlist(as.list(x_original[rows, cols])))
-
+      
       tryCatch(
         # insert into original table
         x_original[rows, cols] <<- to,
         warning = function(w) {
-          if (w$message %like% 'invalid factor level') {
-            warning('Value "', to, '" could not be applied to column(s) `', paste(cols, collapse = '`, `'), '` because this value is not an existing factor level.', call. = FALSE)
+          if (w$message %like% "invalid factor level") {
+            x_original <<- x_original %>% mutate_at(vars(cols), ~factor(x = as.character(.), levels = c(to, levels(.))))
+            x <<- x %>% mutate_at(vars(cols), ~factor(x = as.character(.), levels = c(to, levels(.))))
+            x_original[rows, cols] <<- to
+            warning('Value "', to, '" added to the factor levels of column(s) `', paste(cols, collapse = "`, `"), "` because this value was not an existing factor level.\nA better way is to use as.rsi() on beforehand on antimicrobial columns to guarantee the right structure.", call. = FALSE)
+            txt_warning()
+            warned <<- FALSE
           } else {
             warning(w$message, call. = FALSE)
+            txt_warning()
+            cat("\n") # txt_warning() does not append a "\n" on itself
           }
-          txt_warning()
         },
         error = function(e) {
           txt_error()
-          stop(e, call. = FALSE)
+          stop(paste0("In row(s) ", paste(rows[1:min(length(rows), 10)], collapse = ","), 
+                      ifelse(length(rows) > 10, "...", ""),
+                      " while writing value '", to, 
+                      "' to column(s) `", paste(cols, collapse = "`, `"), 
+                      "`:\n", e$message),
+               call. = FALSE)
         }
       )
-
-      x[rows, cols] <<- x_original[rows, cols]
-
-      after <- as.character(unlist(as.list(x_original[rows, cols])))
-
-      # before_df might not be a data.frame, but a tibble of data.table instead
-      old <- as.data.frame(before_df, stringsAsFactors = FALSE)[rows,]
-      no_of_changes_this_run <- 0
-      for (i in 1:length(cols)) {
+      
+      tryCatch(
+        x[rows, cols] <<- x_original[rows, cols],
+        error = function(e) {
+          stop(paste0("In row(s) ", paste(rows[1:min(length(rows), 10)], collapse = ","),
+                      "... while writing value '", to, 
+                      "' to column(s) `", paste(cols, collapse = "`, `"), 
+                      "`:\n", e$message), call. = FALSE)
+        }
+      )
+      
+      # before_df might not be a data.frame, but a tibble or data.table instead
+      old <- as.data.frame(before_df, stringsAsFactors = FALSE)[rows, ]
+      track_changes <- list(added = 0,
+                            changed = 0)
+      for (i in seq_len(length(cols))) {
         verbose_new <- data.frame(row = rows,
                                   col = cols[i],
                                   mo_fullname = x[rows, "fullname"],
-                                  old = as.character(old[, cols[i]]),
-                                  new = as.character(x[rows, cols[i]]),
+                                  old = as.rsi(as.character(old[, cols[i]]), warn = FALSE),
+                                  new = as.rsi(as.character(x[rows, cols[i]])),
                                   rule = strip_style(rule[1]),
                                   rule_group = strip_style(rule[2]),
                                   rule_name = strip_style(rule[3]),
                                   stringsAsFactors = FALSE)
         colnames(verbose_new) <- c("row", "col", "mo_fullname", "old", "new", "rule", "rule_group", "rule_name")
         verbose_new <- verbose_new %>% filter(old != new | is.na(old))
+        # save changes to data set 'verbose_info'
         verbose_info <<- rbind(verbose_info, verbose_new)
-        no_of_changes_this_run <- no_of_changes_this_run + nrow(verbose_new)
+        # count adds and changes
+        track_changes$added <- track_changes$added + verbose_new %>% filter(is.na(old)) %>% nrow()
+        track_changes$changed <- track_changes$changed + verbose_new %>% filter(!is.na(old)) %>% nrow()
       }
-      # return number of (new) changes
-      return(no_of_changes_this_run)
+      # after the applied changes: return list with counts of added and changed
+      return(track_changes)
     }
-    # return number of (new) changes: none.
-    return(0)
+    # no changes were applied: return number of (new) changes: none.
+    return(list(added = 0,
+                changed = 0))
   }
-
+  
   # save original table
   x_original <- x
-
+  
   # join to microorganisms data set
   suppressWarnings(
     x <- x %>%
@@ -445,13 +508,13 @@ eucast_rules <- function(x,
              genus_species = paste(genus, species)) %>%
       as.data.frame(stringsAsFactors = FALSE)
   )
-
+  
   if (info == TRUE) {
     cat(paste0(
       "\nRules by the ", bold("European Committee on Antimicrobial Susceptibility Testing (EUCAST)"),
       "\n", blue("http://eucast.org/"), "\n"))
   }
-
+  
   # since ampicillin ^= amoxicillin, get the first from the latter (not in original EUCAST table)
   if (!ab_missing(AMP) & !ab_missing(AMX)) {
     if (verbose == TRUE) {
@@ -473,7 +536,8 @@ eucast_rules <- function(x,
     message(blue(paste0("NOTE: Using column `", bold(AMX), "` as input for ampicillin (J01CA01) since many EUCAST rules depend on it.")))
     AMP <- AMX
   }
-
+  
+  # nolint start
   # antibiotic classes
   aminoglycosides <- c(TOB, GEN, KAN, NEO, NET, SIS)
   tetracyclines <- c(DOX, MNO, TCY) # since EUCAST v3.1 tigecycline (TGC) is set apart
@@ -488,32 +552,75 @@ eucast_rules <- function(x,
   ureidopenicillins <- c(PIP, TZP, AZL, MEZ)
   all_betalactams <- c(aminopenicillins, cephalosporins, carbapenems, ureidopenicillins, AMC, OXA, FLC, PEN)
   fluoroquinolones <- c(OFX, CIP, NOR, LVX, MFX)
-
+  # nolint end
+  
   # Help function to get available antibiotic column names ------------------
   get_antibiotic_columns <- function(x, df) {
     x <- trimws(unlist(strsplit(x, ",", fixed = TRUE)))
     y <- character(0)
-    for (i in 1:length(x)) {
+    for (i in seq_len(length(x))) {
+      if (is.function(get(x[i]))) {
+        stop("Column ", x[i], " is also a function. Please create an issue on github.com/msberends/AMR/issues.")
+      }
       y <- c(y, tryCatch(get(x[i]), error = function(e) ""))
     }
     y[y != "" & y %in% colnames(df)]
   }
-
+  get_antibiotic_names <- function(x) {
+    x %>%
+      strsplit(",") %>%
+      unlist() %>%
+      trimws() %>%
+      sapply(function(x) if (x %in% AMR::antibiotics$ab) ab_name(x, language = NULL, tolower = TRUE) else x) %>%
+      sort() %>%
+      paste(collapse = ", ")
+  }
+  format_antibiotic_names <- function(ab_names, ab_results) {
+    ab_names <- trimws(unlist(strsplit(ab_names, ",")))
+    ab_results <- trimws(unlist(strsplit(ab_results, ",")))
+    if (length(ab_results) == 1) {
+      if (length(ab_names) == 1) {
+        # like FOX S
+        x <- paste(ab_names, "is")
+      } else if (length(ab_names) == 2) {
+        # like PEN,FOX S
+        x <- paste(paste0(ab_names, collapse = " and "), "are both")
+      } else {
+        # like PEN,FOX,GEN S (although dependency on > 2 ABx does not exist at the moment)
+        x <- paste(paste0(ab_names, collapse = " and "), "are all")
+      }
+      return(paste0(x, " '", ab_results, "'"))
+    } else {
+      if (length(ab_names) == 2) {
+        # like PEN,FOX S,R
+        paste0(ab_names[1], " is '", ab_results[1], "' and ", 
+               ab_names[2], " is '", ab_results[2], "'")
+      } else {
+        # like PEN,FOX,GEN S,R,R (although dependency on > 2 ABx does not exist at the moment)
+        paste0(ab_names[1], " is '", ab_results[1], "' and ", 
+               ab_names[2], " is '", ab_results[2], "' and ", 
+               ab_names[3], " is '", ab_results[3], "'")
+      }
+    }
+  }
+  
   eucast_rules_df <- eucast_rules_file # internal data file
-  no_of_changes <- 0
-  for (i in 1:nrow(eucast_rules_df)) {
-
+  no_added <- 0
+  no_changed <- 0
+  for (i in seq_len(nrow(eucast_rules_df))) {
+    
     rule_previous <- eucast_rules_df[max(1, i - 1), "reference.rule"]
     rule_current <- eucast_rules_df[i, "reference.rule"]
     rule_next <- eucast_rules_df[min(nrow(eucast_rules_df), i + 1), "reference.rule"]
     rule_group_previous <- eucast_rules_df[max(1, i - 1), "reference.rule_group"]
     rule_group_current <- eucast_rules_df[i, "reference.rule_group"]
-    rule_group_next <- eucast_rules_df[min(nrow(eucast_rules_df), i + 1), "reference.rule_group"]
     if (is.na(eucast_rules_df[i, 4])) {
-      rule_text <- paste("always:", eucast_rules_df[i, 6], "=", eucast_rules_df[i, 7])
+      rule_text <- paste0("always report as '", eucast_rules_df[i, 7], "': ", get_antibiotic_names(eucast_rules_df[i, 6]))
     } else {
-      rule_text <- paste("if", eucast_rules_df[i, 4], "=", eucast_rules_df[i, 5],
-                         "then", eucast_rules_df[i, 6], "=", eucast_rules_df[i, 7])
+      rule_text <- paste0("report as '", eucast_rules_df[i, 7], "' when ",
+                          format_antibiotic_names(ab_names = get_antibiotic_names(eucast_rules_df[i, 4]),
+                                                  ab_results = eucast_rules_df[i, 5]), ": ",
+                          get_antibiotic_names(eucast_rules_df[i, 6]))
     }
     if (i == 1) {
       rule_previous <- ""
@@ -521,9 +628,8 @@ eucast_rules <- function(x,
     }
     if (i == nrow(eucast_rules_df)) {
       rule_next <- ""
-      rule_group_next <- ""
     }
-
+    
     # don't apply rules if user doesn't want to apply them
     if (rule_group_current %like% "breakpoint" & !any(c("all", "breakpoints") %in% rules)) {
       next
@@ -534,8 +640,8 @@ eucast_rules <- function(x,
     if (rule_group_current %like% "other" & !any(c("all", "other") %in% rules)) {
       next
     }
-
-
+    
+    
     if (info == TRUE) {
       # Print rule (group) ------------------------------------------------------
       if (rule_group_current != rule_group_previous) {
@@ -563,17 +669,17 @@ eucast_rules <- function(x,
         warned <- FALSE
       }
     }
-
+    
     # Get rule from file ------------------------------------------------------
     col_mo_property <- eucast_rules_df[i, 1]
     like_is_one_of <- eucast_rules_df[i, 2]
-
+    
     # be sure to comprise all coagulase-negative/-positive Staphylococci when they are mentioned
     if (eucast_rules_df[i, 3] %like% "coagulase-") {
       suppressWarnings(
         all_staph <- AMR::microorganisms %>%
           filter(genus == "Staphylococcus") %>%
-          mutate(CNS_CPS = mo_fullname(mo, Becker = "all"))
+          mutate(CNS_CPS = mo_name(mo, Becker = "all"))
       )
       if (eucast_rules_df[i, 3] %like% "coagulase-") {
         eucast_rules_df[i, 3] <- paste0("^(",
@@ -592,11 +698,11 @@ eucast_rules <- function(x,
       }
       like_is_one_of <- "like"
     }
-
+    
     if (like_is_one_of == "is") {
       mo_value <- paste0("^", eucast_rules_df[i, 3], "$")
     } else if (like_is_one_of == "one_of") {
-      # "Clostridium, Actinomyces, ..." -> "^(Clostridium|Actinomyces|...)$"
+      # so 'Clostridium, Actinomyces, ...' will turn into '^(Clostridium|Actinomyces|...)$'
       mo_value <- paste0("^(",
                          paste(trimws(unlist(strsplit(eucast_rules_df[i, 3], ",", fixed = TRUE))),
                                collapse = "|"),
@@ -606,12 +712,12 @@ eucast_rules <- function(x,
     } else {
       stop("invalid like_is_one_of", call. = FALSE)
     }
-
+    
     source_antibiotics <- eucast_rules_df[i, 4]
     source_value <- trimws(unlist(strsplit(eucast_rules_df[i, 5], ",", fixed = TRUE)))
     target_antibiotics <- eucast_rules_df[i, 6]
     target_value <- eucast_rules_df[i, 7]
-
+    
     if (is.na(source_antibiotics)) {
       rows <- tryCatch(which(x[, col_mo_property] %like% mo_value),
                        error = function(e) integer(0))
@@ -641,24 +747,28 @@ eucast_rules <- function(x,
         stop("only 3 antibiotics supported for source_antibiotics ", call. = FALSE)
       }
     }
-
+    
     cols <- get_antibiotic_columns(target_antibiotics, x)
-
+    
     # Apply rule on data ------------------------------------------------------
     # this will return the unique number of changes
-    no_of_changes <- no_of_changes + edit_rsi(to = target_value,
-                                              rule = c(rule_text, rule_group_current, rule_current),
-                                              rows = rows,
-                                              cols = cols)
-
+    run_changes <- edit_rsi(to = target_value,
+                            rule = c(rule_text, rule_group_current, rule_current),
+                            rows = rows,
+                            cols = cols)
+    no_added <- no_added + run_changes$added
+    no_changed <- no_changed + run_changes$changed
+    
     # Print number of new changes ---------------------------------------------
     if (info == TRUE & rule_next != rule_current) {
       # print only on last one of rules in this group
-      txt_ok(no_of_changes = no_of_changes)
-      no_of_changes <- 0
+      txt_ok(no_added = no_added, no_changed = no_changed)
+      # and reset counters
+      no_added <- 0
+      no_changed <- 0
     }
   }
-
+  
   # Print overview ----------------------------------------------------------
   if (info == TRUE) {
     if (verbose == TRUE) {
@@ -666,24 +776,24 @@ eucast_rules <- function(x,
     } else {
       wouldve <- ""
     }
-
+    
     verbose_info <- verbose_info %>%
       arrange(row, rule_group, rule_name, col)
-
-    cat(paste0("\n", silver(strrep("-", options()$width - 1)), "\n"))
-    cat(bold(paste('EUCAST rules', paste0(wouldve, 'affected'),
+    
+    cat(paste0("\n", grey(strrep("-", options()$width - 1)), "\n"))
+    cat(bold(paste("EUCAST rules", paste0(wouldve, "affected"),
                    formatnr(n_distinct(verbose_info$row)),
-                   'out of', formatnr(nrow(x_original)),
-                   'rows, making a total of', formatnr(nrow(verbose_info)), 'edits\n')))
-
+                   "out of", formatnr(nrow(x_original)),
+                   "rows, making a total of", formatnr(nrow(verbose_info)), "edits\n")))
+    
     n_added <- verbose_info %>% filter(is.na(old)) %>% nrow()
     n_changed <- verbose_info %>% filter(!is.na(old)) %>% nrow()
-
+    
     # print added values ----
     if (n_added == 0) {
       colour <- cat # is function
     } else {
-      colour <- blue # is function
+      colour <- green # is function
     }
     cat(colour(paste0("=> ", wouldve, "added ",
                       bold(formatnr(verbose_info %>%
@@ -693,8 +803,6 @@ eucast_rules <- function(x,
     if (n_added > 0) {
       verbose_info %>%
         filter(is.na(old)) %>%
-        # sort it well: S < I < R
-        mutate(new = as.rsi(new)) %>%
         group_by(new) %>%
         summarise(n = n()) %>%
         mutate(plural = ifelse(n > 1, "s", ""),
@@ -703,7 +811,7 @@ eucast_rules <- function(x,
         paste("   -", ., collapse = "\n") %>%
         cat()
     }
-
+    
     # print changed values ----
     if (n_changed == 0) {
       colour <- cat # is function
@@ -721,9 +829,6 @@ eucast_rules <- function(x,
     if (n_changed > 0) {
       verbose_info %>%
         filter(!is.na(old)) %>%
-        # sort it well: S < I < R
-        mutate(old = as.rsi(old),
-               new = as.rsi(new)) %>%
         group_by(old, new) %>%
         summarise(n = n()) %>%
         mutate(plural = ifelse(n > 1, "s", ""),
@@ -733,13 +838,15 @@ eucast_rules <- function(x,
         cat()
       cat("\n")
     }
-    cat(paste0(silver(strrep("-", options()$width - 1)), "\n"))
-
+    cat(paste0(grey(strrep("-", options()$width - 1)), "\n"))
+    
     if (verbose == FALSE & nrow(verbose_info) > 0) {
-      cat(paste("\nUse", bold("verbose = TRUE"), "to get a data.frame with all specified edits instead.\n"))
+      cat(paste("\nUse", bold("eucast_rules(..., verbose = TRUE)"), "(on your original data) to get a data.frame with all specified edits instead.\n\n"))
+    } else if (verbose == TRUE) {
+      cat(paste0("\nUsed 'Verbose mode' (", bold("verbose = TRUE"), "), which returns a data.frame with all specified edits.\nUse ", bold("verbose = FALSE"), " to apply the rules on your data.\n\n"))
     }
   }
-
+  
   # Return data set ---------------------------------------------------------
   if (verbose == TRUE) {
     verbose_info
@@ -747,4 +854,3 @@ eucast_rules <- function(x,
     x_original
   }
 }
-
