@@ -23,22 +23,22 @@ context("filter_ab_class.R")
 
 test_that("ATC-group filtering works", {
   library(dplyr)
-  expect_gt(septic_patients %>% filter_ab_class("carbapenem") %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_aminoglycosides() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_carbapenems() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_cephalosporins() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_1st_cephalosporins() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_2nd_cephalosporins() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_3rd_cephalosporins() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_4th_cephalosporins() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_fluoroquinolones() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_glycopeptides() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_macrolides() %>% nrow(), 0)
-  expect_gt(septic_patients %>% filter_tetracyclines() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_ab_class("carbapenem") %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_aminoglycosides() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_carbapenems() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_cephalosporins() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_1st_cephalosporins() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_2nd_cephalosporins() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_3rd_cephalosporins() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_4th_cephalosporins() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_fluoroquinolones() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_glycopeptides() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_macrolides() %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_tetracyclines() %>% nrow(), 0)
 
-  expect_gt(septic_patients %>% filter_carbapenems("R", "all") %>% nrow(), 0)
+  expect_gt(example_isolates %>% filter_carbapenems("R", "all") %>% nrow(), 0)
 
-  expect_error(septic_patients %>% filter_carbapenems(result = "test"))
-  expect_error(septic_patients %>% filter_carbapenems(scope = "test"))
-  expect_warning(septic_patients %>% select(1:3) %>% filter_carbapenems())
+  expect_error(example_isolates %>% filter_carbapenems(result = "test"))
+  expect_error(example_isolates %>% filter_carbapenems(scope = "test"))
+  expect_warning(example_isolates %>% select(1:3) %>% filter_carbapenems())
 })
